aboutsummaryrefslogtreecommitdiff
path: root/scripts/unique_objects_generator.py
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/unique_objects_generator.py')
-rw-r--r--scripts/unique_objects_generator.py8
1 files changed, 7 insertions, 1 deletions
diff --git a/scripts/unique_objects_generator.py b/scripts/unique_objects_generator.py
index 78526a3e..289a5bbe 100644
--- a/scripts/unique_objects_generator.py
+++ b/scripts/unique_objects_generator.py
@@ -157,6 +157,8 @@ class UniqueObjectsOutputGenerator(OutputGenerator):
'vkGetDisplayModeProperties2KHR',
'vkCreateRenderPass',
'vkDestroyRenderPass',
+ 'vkSetDebugUtilsObjectNameEXT',
+ 'vkSetDebugUtilsObjectTagEXT',
]
# Commands shadowed by interface functions and are not implemented
self.interface_functions = [
@@ -165,10 +167,14 @@ class UniqueObjectsOutputGenerator(OutputGenerator):
'vkGetDisplayPlaneSupportedDisplaysKHR',
'vkGetDisplayModePropertiesKHR',
'vkGetDisplayPlaneCapabilitiesKHR',
# DebugReport APIs are hooked, but handled separately in the source file
'vkCreateDebugReportCallbackEXT',
'vkDestroyDebugReportCallbackEXT',
'vkDebugReportMessageEXT',
+ # VK_EXT_debug_utils APIs are hooked, but handled separately in the source file
+ 'vkCreateDebugUtilsMessengerEXT',
+ 'vkDestroyDebugUtilsMessengerEXT',
+ 'vkSubmitDebugUtilsMessageEXT',
]
self.headerVersion = None
# Internal state - accumulators for different inner block text
@@ -165,10 +167,14 @@ class UniqueObjectsOutputGenerator(OutputGenerator):
'vkGetDisplayModePropertiesKHR',
'vkGetDisplayPlaneCapabilitiesKHR',
- # DebugReport APIs are hooked, but handled separately in the source file
+ # VK_EXT_debug_report APIs are hooked, but handled separately in the source file
'vkCreateDebugReportCallbackEXT',
'vkDestroyDebugReportCallbackEXT',